function [neighborIds bestneighborIds]  = gmmknnclassify(queryMatrix, dataMatrix, label, SR_EMD_para)
% gmmknnclassify 
%
% Please cite the following paper if you use the code:
%
% Peihua Li,  Qilong Wang, Lei Zhang. A Novel Earth Mover's Distance Methodology for Image Matching with 
%Gaussian Mixture Models. IEEE Int. Conf. on Computer Vision (ICCV), 2013.
%
% For questions,  please conact:  Qilong Wang  (Email:  wangqilong.415@163.com), 
%                                               Peihua  Li (Email: peihuali at dlut dot edu dot cn) 
%                                               Lei zhang (Email: cslzhang  at comp dot polyu dot edu dot hk)
%
% The software is provided ''as is'' and without warranty of any kind,
% experess, implied or otherwise, including without limitation, any
% warranty of merchantability or fitness for a particular purpose.

k = SR_EMD_para.k;
neighborIds = zeros(size(queryMatrix,1),k);
bestneighborIds = zeros(size(queryMatrix,1),1);
neighborDistances = neighborIds;

numDataVectors = size(dataMatrix,1);
numQueryVectors = size(queryMatrix,1);

dist = zeros(numDataVectors,1);

if strcmp('EMD-M', SR_EMD_para.DistanceType) == 1
      for i=1:numQueryVectors
           for j=1:numDataVectors
             dist(j) = SR_EMD(queryMatrix{i}, dataMatrix{j},  SR_EMD_para);   
           end
           [sortval sortpos] = sort(dist,'ascend');
           if k>1
               neighborIds(i,:) = sortpos(1:k);
               neighborDistances(i,:) = sortval(1:k);
               bestneighborIds(i) = getbest(label(neighborIds(i,:)));
           else
               [sorted,index] = min(dist);
               neighborDistances(i,k) = sorted;
               bestneighborIds(i) = label(index);
           end
      end
elseif strcmp('EMD-theta', SR_EMD_para.DistanceType) == 1
      for i=1:numQueryVectors
           for j=1:numDataVectors
             dist(j) = SR_EMD(queryMatrix{i}, dataMatrix{j}, SR_EMD_para);   
           end
           [sortval sortpos] = sort(dist,'ascend');
           if k>1
               neighborIds(i,:) = sortpos(1:k);
               neighborDistances(i,:) = sortval(1:k);
               bestneighborIds(i) = getbest(label(neighborIds(i,:)));
           else
               [sorted,index] = min(dist);
               neighborDistances(i,k) = sorted;
               bestneighborIds(i) = label(index);
           end
      end
end
end

function [Bestindex] = getbest(label)
    A = unique(label);
    n = histc(label,A);
    [c index] = max(n);
    if c>1
        Bestindex = A(index);
    else
        Bestindex  = label(1);
    end
end