function      [] = CalculateDescriptors(feature_type,   patch_size,  grid_spacing,     maxImageSize,   imageBaseDir,     dataBaseDir,   image_suffix,  canSkip)
% CalculateDescriptors compute image feature and  save the features
% on disk.
%
% feature_type:     The type of generated descriptor, L2ECM is used here but other features can be used.
% patch_size:        The size of patch in which a descriptor is computed
% grid_spacing:     The sampling spacing of dense descriptors
% maxImageSize: The allowable maximum size of image.
% imageBaseDir:  The base directory for the image files.
% dataBaseDir:    The base directory for the data files that are generated
%                        by the algorithm.
% image_suffix:    The suffix of input images.
% canSkip:      Flag whether we can skip if the descriptors have been computed
%
% Please cite the following paper if you use the code:
%
% Peihua Li,  Qilong Wang, Lei Zhang. A Novel Earth Mover's Distance Methodology for Image Matching with 
%Gaussian Mixture Models. IEEE Int. Conf. on Computer Vision (ICCV), 2013.
%
% For questions,  please conact:  Qilong Wang  (Email:  wangqilong.415@163.com), 
%                                               Peihua  Li (Email: peihuali at dlut dot edu dot cn) 
%
% The software is provided ''as is'' and without warranty of any kind,
% experess, implied or otherwise, including without limitation, any
% warranty of merchantability or fitness for a particular purpose.


fnames = dir(fullfile(imageBaseDir, sprintf('*%s', image_suffix)));
imageFileList = cell( length(fnames),1);
for f = 1: length(fnames)
    imageFileList{f} = fnames(f).name;
end


fprintf('Extracting dense descriptors --Processing %s', imageBaseDir);
for f =1:size(imageFileList,1)

    if ~mod(f, 5)
        fprintf('.');
    end
    
    curr_filename = imageFileList{f};

    suffix_pos = findstr(curr_filename, image_suffix);
    outFName = fullfile(dataBaseDir, [curr_filename(1:suffix_pos-1) '.mat']);
    if canSkip && size(dir(outFName), 1)
        continue;
    end

    imageFName = fullfile(imageBaseDir, curr_filename);
    I = sp_load_image(imageFName);
    [hgt wid] = size(I);
    if max(hgt,wid) > maxImageSize    
        I = imresize(I, maxImageSize/max(hgt,wid), 'bicubic'); 
        [hgt wid] = size(I);
    end
     
    if strcmp(feature_type, 'L2ECM')
       dataArr = covcalculatorwithcheck(I, patch_size, grid_spacing, 0);
    elseif strcmp('user-defined',featureType) == 1 
        % Other features can be used
    end
    
    sp_make_dir(outFName);
    save(outFName, 'dataArr');
end
fprintf('Completed.\n');

end