function [fimage] = buildfeatures(inimage)
% buildfeatures generates raw feature for L2ECM image feature.
%
% Please cite the following paper if you use the code:
%
%Peihua Li,  Qilong Wang: Local Log-Euclidean Covariance Matrix (L2ECM) for Image 
%Representation and Its Applications, (ECCV) 2012.
% For questions,  please conact:  Qilong Wang  (Email:  wangqilong.415@163.com), 
%                                               Peihua  Li (Email: peihuali at dlut dot edu dot cn) 
%
% The software is provided ''as is'' and without warranty of any kind,
% experess, implied or otherwise, including without limitation, any
% warranty of merchantability or fitness for a particular purpose.

[height width depth] = size(inimage);

fdim = 5;

filter=fspecial('gaussian',3,0.5);
gimage = conv2(inimage, filter, 'same'); 

filter = [-3 5 5;-3 0 5;-3 -3 -3]; 
filter1 = [5 5 -3;5 0 -3;-3 -3 -3]; 

%horizontal edge
himage = conv2(gimage, filter, 'same');
%vertical edge
vimage = conv2(gimage, filter1, 'same');


%horizontal 2nd derivative
shimage = conv2(himage, filter, 'same');
%vertical 2nd derivative     
svimage = conv2(vimage, filter1, 'same');

fimage = zeros(height, width, fdim);
fimage(:,:,1)   = gimage;
fimage(:,:,2)   = abs(himage);
fimage(:,:,3)   = abs(vimage);
fimage(:,:,4)   = abs(shimage);
fimage(:,:,5)   = abs(svimage);

end

